@@ -10,12 +10,11 @@ from matplotlib.axis import Axis
 from matplotlib.transforms import Bbox
 import numpy as numpy
 from pandas import DataFrame
-import pandas.util
 from pyproj import CRS, Transformer
 from shapely import ops
 from shapely.geometry import Point, Polygon
-from stormevents import VortexTrack
-from stormevents.nhc.atcf import ATCF_FileDeck, ATCF_Mode
+from stormevents.nhc import VortexTrack
+from stormevents.nhc.atcf import ATCF_Mode
 from stormevents.nhc.track import read_atcf
 import utm
 
@@ -25,10 +24,6 @@ from adcircpy.utilities import get_logger
 
 LOGGER = get_logger(__name__)
 
-# suppress `SettingWithCopyWarning` when instantiating `VortexForcing`
-# TODO: figure out why that is happening
-pandas.options.mode.chained_assignment = None  # default='warn'
-
 
 class BestTrackForcing(VortexTrack, WindForcing):
     def __init__(
@@ -57,7 +52,7 @@ class BestTrackForcing(VortexTrack, WindForcing):
             storm=storm,
             start_date=start_date,
             end_date=end_date,
-            file_deck=ATCF_FileDeck.b,
+            file_deck='b',
             mode=mode,
             record_type='BEST',
             filename=filename,
@@ -190,10 +185,10 @@ class BestTrackForcing(VortexTrack, WindForcing):
             ]
         )
         _switch = True
-        unique_dates = numpy.unique(self.dataframe['datetime'])
+        unique_dates = numpy.unique(self.data['datetime'])
         _found_start_date = False
         for _datetime in unique_dates:
-            records = self.dataframe[self.dataframe['datetime'] == _datetime]
+            records = self.data[self.data['datetime'] == _datetime]
             radii = records['radius_of_last_closed_isobar'].iloc[0]
             radii = 1852.0 * radii  # convert to meters
             lon = records['longitude'].iloc[0]
@@ -237,15 +232,15 @@ class BestTrackForcing(VortexTrack, WindForcing):
         if axis is None:
             fig = pyplot.figure()
             axis = fig.add_subplot(111)
-        for i in range(len(self.speed)):
+        data = self.data
+        for i, (_, row) in enumerate(data.iterrows()):
             # when dealing with nautical degrees, U is sine and V is cosine.
-            U = self.speed.iloc[i] * numpy.sin(numpy.deg2rad(self.direction.iloc[i]))
-            V = self.speed.iloc[i] * numpy.cos(numpy.deg2rad(self.direction.iloc[i]))
-            axis.quiver(self.longitude.iloc[i], self.latitude.iloc[i], U, V, **kwargs)
+            U = row['speed'] * numpy.sin(numpy.deg2rad(row['direction']))
+            V = row['speed'] * numpy.cos(numpy.deg2rad(row['direction']))
+            axis.quiver(row['longitude'], row['latitude'], U, V, **kwargs)
             if i % 6 == 0:
                 axis.annotate(
-                    self.data['datetime'].iloc[i],
-                    (self.longitude.iloc[i], self.latitude.iloc[i]),
+                    row['datetime'], (row['longitude'], row['latitude']),
                 )
         if show:
             axis.axis('scaled')
