@@ -1,4 +1,5 @@
 #! /usr/bin/env python
+from copy import copy
 
 import pytest
 
@@ -9,17 +10,17 @@ from tests import OUTPUT_DIRECTORY
 @pytest.fixture
 def nodes() -> {int: ((float, float), float)}:
     return {
-        '1': ((0.0, 0.0), -5.0),
-        '2': ((0.5, 0.0), -4.0),
-        '3': ((1.0, 0.0), -3.0),
-        '4': ((1.0, 1.0), -2.0),
-        '5': ((0.0, 1.0), -1.0),
-        '6': ((0.5, 1.5), 0.0),
-        '7': ((0.33, 0.33), 1.0),
-        '8': ((0.66, 0.33), 2.0),
-        '9': ((0.5, 0.66), 3.0),
-        '10': ((-1.0, 1.0), 4.0),
-        '11': ((-1.0, 0.0), 5.0),
+        '1': (0.0, 0.0, -5.0),
+        '2': (0.5, 0.0, -4.0),
+        '3': (1.0, 0.0, -3.0),
+        '4': (1.0, 1.0, -2.0),
+        '5': (0.0, 1.0, -1.0),
+        '6': (0.5, 1.5, 0.0),
+        '7': (0.33, 0.33, 1.0),
+        '8': (0.66, 0.33, 2.0),
+        '9': (0.5, 0.66, 3.0),
+        '10': (-1.0, 1.0, 4.0),
+        '11': (-1.0, 0.0, 5.0),
     }
 
 
@@ -55,7 +56,7 @@ def boundaries() -> {int: {int: {str: [int]}}}:
 def fort14(elements, nodes) -> str:
     lines = [
         f'\n{len(elements):d} {len(nodes):d}',
-        *(f'{id} {x} {y} {z}' for id, ((x, y), z) in nodes.items()),
+        *(f'{id} {x} {y} {z}' for id, (x, y, z) in nodes.items()),
         *(
             f'{id} {len(geometry)} {" ".join(idx for idx in geometry)}'
             for id, geometry in elements.items()
@@ -67,11 +68,11 @@ def fort14(elements, nodes) -> str:
 @pytest.fixture
 def wet_nodes() -> {int: ((float, float), float)}:
     return {
-        0: ((0.0, 0.0), 0.0),
-        1: ((1.0, 0.0), -1.0),
-        2: ((1.0, 1.0), -2.0),
-        3: ((0.0, 1.0), -3.0),
-        4: ((0.5, 1.5), -4.0),
+        0: (0.0, 0.0, 0.0),
+        1: (1.0, 0.0, -1.0),
+        2: (1.0, 1.0, -2.0),
+        3: (0.0, 1.0, -3.0),
+        4: (0.5, 1.5, -4.0),
     }
 
 
@@ -148,23 +149,39 @@ def test_write(nodes, elements):
     mesh.write(output_directory / 'test_AdcircMesh.gr3', overwrite=True)
     mesh.write(output_directory / 'test_AdcircMesh.2dm', format='2dm', overwrite=True)
 
-    with pytest.raises(FileExistsError):
-        mesh.write(output_directory / 'test_AdcircMesh.2dm', format='2dm')
-
     with pytest.raises(ValueError):
         mesh.write(output_directory / 'test_AdcircMesh.txt', format='txt', overwrite=True)
 
 
 def test_triplot(nodes, elements, boundaries, mocker):
-    mesh = AdcircMesh(nodes, elements, boundaries)
+    mesh = AdcircMesh(nodes, elements, boundaries=boundaries)
 
     mocker.patch('matplotlib.pyplot.show')
     mesh.triplot()
 
 
 def test_make_plot_flat_domain(nodes, elements, boundaries, mocker):
-    nodes = {id: (coord, 0.0) for id, (coord, _) in nodes.items()}
-    mesh = AdcircMesh(nodes, elements, boundaries)
+    nodes = {id: (*coord[:2], 0.0) for id, coord in nodes.items()}
+    mesh = AdcircMesh(nodes, elements, boundaries=boundaries)
 
     mocker.patch('matplotlib.pyplot.show')
     mesh.make_plot()
+
+
+def test_mesh_equality(nodes, elements, boundaries, wet_nodes, wet_elements):
+    mesh_1 = AdcircMesh(nodes, elements, boundaries=boundaries)
+    mesh_2 = AdcircMesh(nodes, elements, boundaries=boundaries)
+    mesh_3 = mesh_1
+    mesh_4 = copy(mesh_1)
+    mesh_5 = AdcircMesh(wet_nodes, wet_elements)
+    mesh_6 = AdcircMesh(nodes, elements)
+
+    assert mesh_1 is not mesh_2
+    assert mesh_1 is mesh_3
+    assert mesh_1 is not mesh_4
+
+    assert mesh_1 == mesh_2
+    assert mesh_1 == mesh_3
+    assert mesh_1 == mesh_4
+    assert mesh_1 != mesh_5
+    assert mesh_1 != mesh_6
